@@ -9,7 +9,7 @@ import sys, string, types
 import collections
 import subprocess
 #import numpy as np  
-#import pandas as pd
+import pandas as pd
 
 def test():
     print("gplfinance.test()")
@@ -75,7 +75,11 @@ def __gnuplot(data, plot_cmd, *args, **kwargs):
             #print('set %s %s' %(k, v))
             g.cmd('set %s %s' %(k, v))
 
-    g.cmd('$Mydata << EOD\n%s\nEOD' %(data))
+    if isinstance(data, pd.DataFrame):
+        content = data.to_csv(sep = ' ')
+    else:
+        content = str(data)
+    g.cmd('$Mydata << EOD\n%s\nEOD' %(content))
     c = plot_cmd
     for cmd in args:
         c += ' $Mydata %s,' %(cmd)
